========================
Wagtail Robots In Action
========================

Here are some images so you can see Wagtail Robots in the Wagtail admin
interface.

In the menu:

.. image:: static/1_in_menu.png


The rules index page:

.. image:: static/2_index.png


Create/edit view:

.. image:: static/3_create_edit.png


Create/edit view with the CondensedInlinePanel:

.. image:: static/4_create_edit_condensed.png


Index view with at 1 rule created:

.. image:: static/5_index_rule.png
